import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:random/cubit/bottom_nav_cubit.dart';
import 'package:random/cubit/settings_cubit.dart';
import 'package:random/ui/screens/about_page.dart';
import 'package:random/ui/screens/demo_page.dart';
import 'package:random/ui/screens/graph_page.dart';
import 'package:random/ui/screens/settings_page.dart';
import 'package:random/ui/widgets/app_bar.dart';
import 'package:random/ui/widgets/bottom_nav_bar.dart';
import 'package:random/ui/widgets/debug_bloc.dart';

class SkeletonScreen extends StatefulWidget {
  const SkeletonScreen({super.key});

  @override
  State<SkeletonScreen> createState() => _SkeletonScreenState();
}

class _SkeletonScreenState extends State<SkeletonScreen> {
  @override
  Widget build(BuildContext context) {
    const List<Widget> pageNavigation = <Widget>[
      DemoPage(),
      GraphPage(),
      SettingsPage(),
      AboutPage(),
    ];

    String debug = '';

    return BlocProvider<SettingsCubit>(
      create: (BuildContext context) => SettingsCubit(),
      child: BlocProvider<BottomNavCubit>(
        create: (BuildContext context) => BottomNavCubit(),
        child: BlocBuilder<BottomNavCubit, int>(
          builder: (BuildContext context, int state) {
            return GestureDetector(
              onHorizontalDragEnd: (dragDetail) {
                debug = dragDetail.velocity.pixelsPerSecond.toString();
                print('debug: ' + debug);

                if (dragDetail.velocity.pixelsPerSecond.dx < 1) {
                  context.read<BottomNavCubit>().moveNext();
                } else {
                  context.read<BottomNavCubit>().movePrevious();
                }
              },
              child: Scaffold(
                extendBodyBehindAppBar: false,
                appBar: StandardAppBar(),
                body: BlocBuilder<BottomNavCubit, int>(
                  builder: (BuildContext context, int state) {
                    return AnimatedSwitcher(
                      duration: const Duration(milliseconds: 300),
                      child: Stack(
                        children: [
                          pageNavigation.elementAt(state),
                          debug != '' ? DebugBloc(content: debug) : SizedBox(),
                        ],
                      ),
                    );
                  },
                ),
                bottomNavigationBar: const BottomNavBar(),
                backgroundColor: Theme.of(context).colorScheme.background,
              ),
            );
          },
        ),
      ),
    );
  }
}
